@@ -149,8 +149,10 @@ class AbstractSICConnector(object):
     ###########################
 
     def on_event(self, event: str) -> None:
-        """Triggered upon any event This can be either an event related to some action called here,
-        or an event related to one of the robot's touch sensors, i.e. one of:
+        """Triggered upon any event
+
+        :param event: This can be either an event related to some action called here, or an event related to one of the
+        robot's touch sensors, i.e. one of:
         RightBumperPressed, RightBumperReleased, LeftBumperPressed, LeftBumperReleased, BackBumperPressed,
         BackBumperReleased, FrontTactilTouched, FrontTactilReleased, MiddleTactilTouched, MiddleTactilReleased,
         RearTactilTouched, RearTactilReleased, HandRightBackTouched, HandRightBackReleased, HandRightLeftTouched,
@@ -162,34 +164,40 @@ class AbstractSICConnector(object):
     def on_posture_changed(self, posture: str) -> None:
         """
         Trigger when the posture has changed.
+
         :param posture: new posture.
-        :return:
         """
         pass
 
     def on_awake_changed(self, is_awake: bool) -> None:
         """
         Trigger when the robot wakes up or goes to rest.
+
         :param is_awake: true if the robot just woke up, false if it just went to rest.
-        :return:
         """
         pass
 
     def on_person_detected(self, x: int, y: int) -> None:
         """Triggered when some person was detected in front of the robot (after a startWatching action was called).
-        The (given x,y) coordinates are of the center of the person's face.
+
+        :param x: x-coordinate of center of person's face.
+        :param y: y-coordinate of center of person's face.
         This is only sent when the people detection service is running. Will be sent as long as a person is detected."""
         pass
 
     def on_face_recognized(self, identifier: str) -> None:
         """Triggered when a specific face was detected in front of the robot (after a startWatching action was called).
+
+        :param identifier: id of a unique face.
         Only sent when the face recognition service is running. Will be sent as long as the face is recognised.
         The identifiers of recognised faces are stored in a file, and will thus persist over a restart of the agent."""
         pass
 
     def on_audio_language(self, language_key: str) -> None:
         """Triggered whenever a language change was requested (for example by the user).
-        Given is the full language key (e.g. nl-NL or en-US)."""
+
+       :param language_key: e.g. nl-NL or en-US.
+       """
         pass
 
     def on_audio_loaded(self, identifier: int) -> None:
@@ -198,33 +206,46 @@ class AbstractSICConnector(object):
 
     def on_audio_intent(self, detection_result: dict) -> None:
         """Triggered whenever an intent was detected (by Dialogflow) on a user's speech.
-        Given is the name of the intent, a list of optional parameters (following from the dialogflow spec), and a confidence value.
+
+        :param: detection_result: result in a protobuffer dict.
+
+        Given is the name of the intent, a list of optional parameters (following from the dialogflow spec),
+        and a confidence value.
         See https://cloud.google.com/dialogflow/docs/intents-loaded_actions-parameters.
+
         The recognized text itself is provided as well, even when no intent was actually matched (i.e. a failure).
-        These are sent as soon as an intent is recognised, which is always after some start_listening action,
+        These are sent as soon as an intent is recognized, which is always after some start_listening action,
         but might come in some time after the final stop_listening action (if there was some intent detected at least).
-        Intents will keep being recognised until stop_listening is called. In that case, this function can still be triggered,
-        containing the recognized text but no intent (and a confidence value of 0)."""
+        Intents will keep being recognized until stop_listening is called.
+        In that case, this function can still be triggered, containing the recognized text but no intent."""
         pass
 
     def on_text_transcript(self, transcript: str) -> None:
         """Triggered directly when any text is recognised by Dialogflow.
+
+        :param transcript: text
         This can give many non-final results, but is useful for matching short texts (like yes/no) directly."""
         pass
 
     def on_text_sentiment(self, sentiment: str) -> None:
-        """Based on all text transcripts (see on_text_transcript), gives a positive or negative sentiment
-        for all these texts (when the sentiment_analysis service is running)."""
+        """Gives a positive or negative sentiment for all text transcripts (see on_text_transcript).
+
+        :param sentiment: positive or negative
+        Only when the sentiment_analysis service is running)."""
         pass
 
     def on_new_audio_file(self, audio_file: str) -> None:
-        """Triggered whenever a new recording has been stored to an audio (WAV) file. See set_record_audio.
+        """Triggered whenever a new recording has been stored to an audio (WAV) file.
+
+        See set_record_audio.
         Given is the name to the recorded file (which is in the folder required by the play_audio function).
         All audio received between the last start_listening and stop_listening calls is recorded."""
         pass
 
     def on_new_picture_file(self, picture_file: str) -> None:
-        """Triggered whenever a new picture has been stored to an image (JPG) file. See take_picture.
+        """Triggered whenever a new picture has been stored to an image (JPG) file.
+
+        See take_picture.
         Given is the path to the taken picture."""
         pass
 
@@ -233,28 +254,26 @@ class AbstractSICConnector(object):
         pass
 
     def on_battery_charge_changed(self, percentage: int) -> None:
-        """
-        Triggered when the battery level changes.
+        """Triggered when the battery level changes.
+
         :param percentage: battery level (0-100)
-        :return:
         """
         pass
 
     def on_charging_changed(self, is_charging: bool) -> None:
         """
         Triggered when the robot is connected (True) or disconnected (False) from a power source.
+
         Warning: is not always accurate, see:
         http://doc.aldebaran.com/2-8/naoqi/sensors/albattery-api.html#BatteryPowerPluggedChanged
         :param is_charging:
-        :return:
         """
         pass
 
     def on_hot_device_detected(self, hot_devices: list) -> None:
-        """
-        Triggered when one or more body parts of the robot become too hot.
+        """Triggered when one or more body parts of the robot become too hot.
+
         :param hot_devices: list of body parts that are too hot.
-        :return:
         """
         pass
 
@@ -263,7 +282,6 @@ class AbstractSICConnector(object):
         Triggered when a motion recording (JSON format) becomes available .
 
         :param motion:
-        :return:
         """
         pass
 
@@ -272,7 +290,6 @@ class AbstractSICConnector(object):
         Triggered when a button has been pressed in the browser
 
         :param button:
-        :return:
         """
         pass
 
