@@ -264,7 +264,7 @@ class BasicSICConnector(AbstractSICConnector):
         if sync:
             inner_callback, lock = self.__build_sync_callback(inner_callback)
 
-        success_callback, _, listen_lock = self.__build_speech_recording_callback(callback)
+        success_callback, _, listen_lock = self.__build_speech_recording_callback(inner_callback)
         self.__register_action_listener('onNewAudioFile', success_callback)
         Thread(target=self.__recording, args=(listen_lock, duration)).start()
 
@@ -386,7 +386,7 @@ class BasicSICConnector(AbstractSICConnector):
     # Event Listeners         #
     ###########################
 
-    def subscribe_event_listener(self, event: str, callback: callable, continuous: bool = False,
+    def subscribe_event_listener(self, event: str, callback: callable = None, continuous: bool = False,
                                  sync: bool = True, load: bool = False) -> None:
         """Subscribe an event listener.
 
@@ -538,11 +538,10 @@ class BasicSICConnector(AbstractSICConnector):
                               callback=callback, event='Breathing' + ('Enabled' if enable else 'Disabled'), sync=sync, load=load)
 
     def go_to_posture(self, posture: Enum, speed: int = 100, callback: callable = None,  sync: bool = True, load: bool = False) -> None:
+        if callback:
+            callback = partial(self.__posture_callback, target_posture=posture, embedded_callback=callback)
         self.__process_action(super(BasicSICConnector, self).go_to_posture, posture.value, speed,
-                              callback=partial(self.__posture_callback,
-                                               target_posture=posture,
-                                               embedded_callback=callback),
-                              event='GoToPostureDone', sync=sync, load=load)
+                              callback=callback, event='GoToPostureDone', sync=sync, load=load)
 
     def __posture_callback(self, target_posture: str, embedded_callback: callable) -> None:
         if self.robot_state['posture'] == target_posture:  # if posture was successfully reached
